scxpand.util.metrics
====================

.. automodule:: scxpand.util.metrics

   
   .. rubric:: Functions

   .. autosummary::
   
      calculate_metrics
      compute_basic_metrics
      evaluate_and_save
      get_score_from_nested_dict
      safe_hmean
   